import 'package:flutter/material.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:supa_test/ads_list.dart';
import 'package:supa_test/auth_page.dart';
import 'package:supabase_flutter/supabase_flutter.dart';


void main() async{

  WidgetsFlutterBinding.ensureInitialized();
  await dotenv.load();
  String supabaseUrl = dotenv.env['SUPABASE_URL']??'';
  String supabaseKey = dotenv.env['SUPABASE_KEY']??'';

  await Supabase.initialize(url: supabaseUrl, anonKey: supabaseKey);
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        debugShowCheckedModeBanner: false,
        title: 'Flutter Supabase',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: const FirstPage()
    );
  }
}


class FirstPage extends StatefulWidget {
  const FirstPage({super.key});

  @override
  State<FirstPage> createState() => _FirstPageState();
}

class _FirstPageState extends State<FirstPage> {


  final SupabaseClient supabaseClient = Supabase.instance.client;
  User? _user;
  @override
  void initState() {
    // TODO: implement initState
    _getAuth();
    super.initState();
  }

  Future<void> _getAuth() async{
    setState(() {
      _user = supabaseClient.auth.currentUser;
    });

    supabaseClient.auth.onAuthStateChange.listen((event) {
      setState(() {
        _user = event.session?.user;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return _user==null ? const AuthPage() : AdsList();
  }
}