import 'dart:io';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:supa_test/pages/text_input.dart';
import 'package:supabase/supabase.dart';
import 'package:supabase_flutter/supabase_flutter.dart';

class SendAds extends StatefulWidget {
  const SendAds({Key? key}) : super(key: key);

  @override
  State<SendAds> createState() => _SendAdsState();
}

class _SendAdsState extends State<SendAds> {

  bool isUploading = false;
  final SupabaseClient supabase = Supabase.instance.client;

  TextEditingController title_controller = TextEditingController();
  TextEditingController desc_controller = TextEditingController();
  TextEditingController price_controller = TextEditingController();
  String city_value = 'تهران';
  String category_value = 'ماشین';
  List<String> cat_list = ['ماشین', 'موبایل', 'خانه', 'لپ تاپ'];
  List<String> city_list = ['تهران', 'شیراز', 'تبریز', 'کرج'];

  Future<String?> uploadFile()async{
        var pickedFile = await FilePicker.platform.pickFiles(allowMultiple: false,type: FileType.image);
    if(pickedFile != null){
      setState(() {
        isUploading = true;
      });
      try{
        File file = File(pickedFile.files.first.path!);
        String fileName = pickedFile.files.first.name;
        String uploadedUrl = await supabase.storage.from('user-images').upload("${supabase.auth.currentUser!.id}/$fileName", file);
        String uploadedUrl2 = await supabase.storage.from('user-images').getPublicUrl("${supabase.auth.currentUser!.id}/$fileName");

        print("urls:");
        print(uploadedUrl2);
        return uploadedUrl2;
       // ScaffoldMessenger.of(context).showSnackBar(const SnackBar(content: Text("File Uploaded Successfully !"),backgroundColor: Colors.green,));
      }catch(e){
        print("ERRROR : $e");
        setState(() {
          isUploading = false;
        });
        ScaffoldMessenger.of(context).showSnackBar(const SnackBar(content: Text("Something went Wrong upload fail")));
        return null;
      }
    }
  }


  Future insertData()async{
    String? img_url = await uploadFile();
    // setState(() {
    //   isUploading = true;
    // });
    try{
      String userId = supabase.auth.currentUser!.id;
      await supabase.from('ads').insert({
        'userid':userId,
                              'title':title_controller.text,
                            'desc':desc_controller.text,
                            "city":city_value,
        "price":int.parse(price_controller.text),
        "img":img_url,
        "category":category_value
      });
     // Navigator.pop(context);
      setState(() {
        isUploading = false;
      });
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text("Success")));

    }catch(e){
      print("Error inserting data : $e");
      setState(() {
        isUploading = false;
      });
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text("Error in insert")));
    }
  }
  @override
  void initState() {
    // TODO: implement initState
    category_value = cat_list[0];
    city_value = city_list[0];
  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Supabase Storage"),
      ),
      body:  Container(
        color: Color(0xfffafafa),
        child: Column(
         children: [
           TextInput(title_controller,'عنوان'),
           TextInput(desc_controller,'توضیحات'),
           TextInput(price_controller,'قیمت'),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
          //    crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              DropdownButton<String>(
                // Step 3.
                value: city_value,
                // Step 4.
                items: city_list
                    .map<DropdownMenuItem<String>>((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: Text(
                      value,
                      style: TextStyle(fontFamily: 'Dana',fontSize: 17.0),
                    ),
                  );
                }).toList(),
                // Step 5.
                onChanged: (String? newValue) {
                  setState(() {
                    city_value = newValue!;
                  });
                },
              ),

              DropdownButton<String>(
                // Step 3.
                value: category_value,
                // Step 4.

                items: cat_list.map<DropdownMenuItem<String>>((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: Text(
                      value,
                      style: TextStyle(fontFamily: 'Dana',fontSize: 17.0),
                    ),
                  );
                }).toList(),
                // Step 5.
                onChanged: (String? newValue) {
                  setState(() {
                    category_value = newValue!;
                  });
                },
              )
            ],
          ),
           Container(
             margin: EdgeInsets.symmetric(vertical: 15.0),
             child: ElevatedButton(
               onPressed: ()async{
                 insertData();
               },
               child: Text("انتخاب تصویر",style: TextStyle(fontFamily: 'Dana',fontSize: 17.0),),
             ),
           )
         ],
        ),
      ),
      floatingActionButton: isUploading ? const CircularProgressIndicator() : FloatingActionButton(
        onPressed: uploadFile,
        child: const Icon(Icons.add_a_photo),

      ),
    );
  }
}
